@@ -5,8 +5,6 @@ import sys, os, os.path
 import sets
 import logging
 
-import code
-
 import ptvDB
 import penguintv
 import Player
@@ -42,17 +40,18 @@ N_FEEDS     = 0
 N_PLAYER    = 1
 N_DOWNLOADS = 2
 
-#import EditTagsMultiDialog
-import TagEditorNG
-import AddSearchTagDialog
-import EditSearchesDialog
-import FeedFilterDialog
-import FeedPropertiesDialog
-import FeedFilterPropertiesDialog
-import SynchronizeDialog
-import FilterSelectorDialog
-import MainWindow, FeedList, EntryList, EntryView, PlanetView, DownloadView, EntryFormatter
+import FeedList, PlanetView, DownloadView, EntryFormatter
 
+if utils.HAS_SEARCH:
+	import FeedFilterPropertiesDialog
+	import AddSearchTagDialog
+	import EditSearchesDialog
+	import FeedFilterDialog
+
+if not utils.RUNNING_HILDON:
+	import SynchronizeDialog
+	import EntryList, EntryView
+	
 if utils.HAS_GSTREAMER:
 	import GStreamerPlayer
 
@@ -121,7 +120,8 @@ class MainWindow(gobject.GObject):
 			self._feed_filter_properties_dialog = FeedFilterPropertiesDialog.FeedFilterPropertiesDialog(gtk.glade.XML(os.path.join(self._glade_prefix,'penguintv.glade'), "window_filter_properties",'penguintv'),self._app)
 		if not utils.RUNNING_SUGAR and not utils.RUNNING_HILDON:
 			self._sync_dialog = SynchronizeDialog.SynchronizeDialog(os.path.join(self._glade_prefix,'penguintv.glade'), self._app)
-
+		
+		self._window_add_feed = None
 		self._filter_selector_dialog = None
 		self._feed_properties_dialog = None
 		
@@ -145,7 +145,7 @@ class MainWindow(gobject.GObject):
 		
 	def __feed_clicked_cb(self, o):
 		if utils.RUNNING_HILDON:
-			self.feed_pane.set_position(0)
+			self.feed_tabs.set_current_page(1)
 				
 	def __entrylistview_list_resized_cb(self, entrylistview, new_width):
 		if self.layout == "widescreen" and self.app_window is not None:			
@@ -289,6 +289,9 @@ class MainWindow(gobject.GObject):
 			
 			self.window.show_all()
 			
+			if not utils.HAS_STATUS_ICON:
+				show_notifs_item.hide()
+			
 			for key in dir(self.__class__): #python insaneness
 				if key[:3] == 'on_':
 					self._widgetTree.signal_connect(key, getattr(self, key))
@@ -307,6 +310,8 @@ class MainWindow(gobject.GObject):
 				self._widgetTree.get_widget('add_feed_filter').hide()
 			if not utils.HAS_MOZILLA:
 				self._widgetTree.get_widget('planet_layout').hide()
+			if not utils.HAS_STATUS_ICON:
+				self._widgetTree.get_widget('show_notifications').hide()
 			self.window = self.app_window
 			
 		self._notebook.show_only(N_FEEDS)
@@ -438,7 +443,10 @@ class MainWindow(gobject.GObject):
 		from sugar.graphics.toolbutton import ToolButton
 		from sugar.graphics.palette import Palette
 		
-		content = self._app.window_add_feed.extract_content()
+		if self._window_add_feed is None:
+			self.show_window_add_feed()
+			self.hide_window_add_feed()
+		content = self._window_add_feed.extract_content()
 		palette = Palette(_('Add Feed'))
 		palette.set_content(content)
 		self.sugar_add_button.set_palette(palette)
@@ -535,10 +543,8 @@ class MainWindow(gobject.GObject):
 
 		if self.layout.endswith("planet"):
 			self._menu_widgettree.get_widget('entry_menu_item').hide()
-			self._menu_widgettree.get_widget('showkept_cb').show()
 		else:
 			self._menu_widgettree.get_widget('entry_menu_item').show()
-			self._menu_widgettree.get_widget('showkept_cb').hide()
 			
 		self.app_window.show_all()
 			
@@ -546,6 +552,18 @@ class MainWindow(gobject.GObject):
 			if key[:3] == 'on_':
 				self._widgetTree.signal_connect(key, getattr(self, key))
 				
+	def show_window_add_feed(self):
+		import AddFeedDialog
+		if self._window_add_feed is None:
+			self._window_add_feed = AddFeedDialog.AddFeedDialog(gtk.glade.XML(self._glade_prefix+'/penguintv.glade', "window_add_feed",'penguintv'),self._app) #MAGIC
+			self._window_add_feed.show()
+			
+	def hide_window_add_feed(self):
+		if self._window_add_feed is None:
+			self.show_window_add_feed()
+			
+		self._window_add_feed.hide()
+				
 	def load_notebook(self):
 		self._notebook = NotebookManager()
 		self._notebook.set_property('tab-border',0)
@@ -648,7 +666,12 @@ class MainWindow(gobject.GObject):
 		self.entry_view.connect('link-activated', self.__link_activated_cb)
 				
 		#major WIDGETS
-		self.feed_pane = components.get_widget('feed_pane')
+		if not utils.RUNNING_HILDON:
+			self.feed_pane = components.get_widget('feed_pane')
+		else:
+			self.feed_tabs = components.get_widget('feed_tabs')
+			self.feed_tabs.set_current_page(1)
+			self.feed_pane = None
 		self._feedlist = components.get_widget('feedlistview')
 		if self.layout.endswith("planet"):
 			self.entry_pane = self.feed_pane #cheat
@@ -715,13 +738,13 @@ class MainWindow(gobject.GObject):
 			if val < 10: val = 50
 			self.entry_pane.set_position(val)
 		
-		if utils.RUNNING_HILDON:
-			val = 840
-		else:
+		if not utils.RUNNING_HILDON:
 			f_p_default = 370
 			val = self._app.db.get_setting(ptvDB.INT, '/apps/penguintv/feed_pane_position', f_p_default)
 			if val < 10: val=50
-		self.feed_pane.connect('realize', self._on_feed_pane_realized, val)
+			
+		if self.feed_pane is not None:
+			self.feed_pane.connect('realize', self._on_feed_pane_realized, val)
 		
 		if not self.changing_layout:
 			self.set_active_filter(FeedList.ALL)
@@ -756,7 +779,8 @@ class MainWindow(gobject.GObject):
 		del self.entry_view
 				
 		#some widgets
-		del self.feed_pane
+		if self.feed_pane is not None:
+			del self.feed_pane
 		del self._feedlist
 		if not self.layout.endswith("planet"):
 			del self.entry_pane
@@ -807,16 +831,15 @@ class MainWindow(gobject.GObject):
 			self.search_container.hide_all()
 			
 		#elif self._notebook.get_current_page() == N_FEEDS:
-		self._app.db.set_setting(ptvDB.INT, '/apps/penguintv/feed_pane_position', self.feed_pane.get_position())
-		self._app.db.set_setting(ptvDB.INT, '/apps/penguintv/entry_pane_position', self.entry_pane.get_position())
+		if self.feed_pane is not None:
+			self._app.db.set_setting(ptvDB.INT, '/apps/penguintv/feed_pane_position', self.feed_pane.get_position())
+		if self.entry_pane is not None:
+			self._app.db.set_setting(ptvDB.INT, '/apps/penguintv/entry_pane_position', self.entry_pane.get_position())
 		if not utils.RUNNING_HILDON:
 			if self.layout.endswith('planet'):
 				self.entry_pane.set_position(0)
 			else:
 				self.feed_pane.set_position(0)
-		else:
-			if self.feed_pane.get_position() > 0:
-				self.feed_pane.set_position(840)
 
 		self._notebook.set_keep_hidden(True)
 		self._widgetTree.get_widget('toolbar1').hide()
@@ -852,9 +875,6 @@ class MainWindow(gobject.GObject):
 			else:
 				val = self._app.db.get_setting(ptvDB.INT, '/apps/penguintv/feed_pane_position', 370)
 				self.feed_pane.set_position(val)
-		else:
-			if self.feed_pane.get_position() > 0:
-				self.feed_pane.set_position(840)
 			
 		self._notebook.set_keep_hidden(False)
 		
@@ -923,7 +943,7 @@ class MainWindow(gobject.GObject):
 			logging.warning("Please wait until feeds have loaded before adding a new one")
 			return 
 		self._notebook.set_current_page(N_FEEDS)
-		self._app.window_add_feed.show() #not modal / blocking
+		self.show_window_add_feed() #not modal / blocking
 		
 	def on_add_feed_filter_activate(self,event):
 		selected = self.feed_list_view.get_selected()
@@ -948,18 +968,19 @@ class MainWindow(gobject.GObject):
 		self._app.toggle_net_connection()
 		
 	def pane_to_feeds(self):
-		self.feed_pane.set_position(840)
+		self.feed_tabs.set_current_page(1)
 		
 	def on_feed_add_clicked(self, event):
 		if self._state == S_MAJOR_DB_OPERATION:
 			logging.warning("Please wait until feeds have loaded before adding a new one")
 			return 
-		self._app.window_add_feed.show() #not modal / blocking
+		self.show_window_add_feed() #not modal / blocking
 	
 	#def on_feed_pane_expose_event(self, widget, event):
 	#	self.feed_list_view.resize_columns(self.feed_pane.get_position())
 	
 	def on_feed_properties_activate(self, event):
+		import FeedPropertiesDialog
 		selected = self.feed_list_view.get_selected()
 		if selected:
 			#title, description, url, link
@@ -1012,6 +1033,7 @@ class MainWindow(gobject.GObject):
 			
 	def on_edit_tags_for_all_activate(self, event):
 		"""Bring up mass tag creation window"""
+		import TagEditorNG
 		window_edit_tags_multi = TagEditorNG.TagEditorNG(gtk.glade.XML(os.path.join(self._glade_prefix,'penguintv.glade'), "dialog_tag_editor_ng",'penguintv'), self._app)
 		window_edit_tags_multi.show()
 			
@@ -1043,26 +1065,30 @@ class MainWindow(gobject.GObject):
 	def on_feeds_poll_clicked(self,event):
 		self._app.poll_feeds()
 		
-	def set_show_kept_menuitem(self, state):
-		self._menu_widgettree.get_widget('showkept_cb').set_active(state)
+	def set_hide_entries_menuitem(self, state):
+		self._menu_widgettree.get_widget('hide_viewed_entries_cb').set_active(state)
 		
-	def set_show_kept_visibility(self, state):
-		assert self.layout.endswith("planet")
-	
+	def set_hide_entries_visibility(self, state):
 		if state:
-			self._menu_widgettree.get_widget('showkept_cb').show()
+			self._menu_widgettree.get_widget('hide_viewed_entries_cb').show()
 		else:
-			self._menu_widgettree.get_widget('showkept_cb').hide()
+			self._menu_widgettree.get_widget('hide_viewed_entries_cb').hide()
 		
-	def on_showkept_cb_toggled(self, event):
-		assert self.layout.endswith("planet")
-		self.entry_list_view.set_show_kept(self._menu_widgettree.get_widget('showkept_cb').get_active())
+	def on_hide_entries_cb_toggled(self, event):
+		self.entry_list_view.set_hide_viewed(self._menu_widgettree.get_widget('hide_viewed_entries_cb').get_active())
+		
+	def on_hide_feeds_cb_toggled(self, checkbox):
+		status = checkbox.get_active()
+		self.feed_list_view.set_unread_toggle(status)
+		self._menu_widgettree.get_widget('hide_viewed_feeds_cb').set_active(status)
+		self._filter_unread_checkbox.set_active(status)
 		
 	def on_synchronize_button_clicked(self,event):
 		self._sync_dialog.hide()
 		self._sync_dialog.on_sync_button_clicked(event)	
 				
 	def on_edit_favorite_tags(self, o=None):
+		import FilterSelectorDialog
 		if self._filter_selector_dialog is None:
 			self._filter_selector_dialog = FilterSelectorDialog.FilterSelectorDialog(gtk.glade.XML(os.path.join(self._glade_prefix,'penguintv.glade'), "dialog_tag_favorites",'penguintv'),self)
 		self._filter_selector_dialog.set_taglists(self._filters, self._favorite_filters)
@@ -1215,7 +1241,7 @@ class MainWindow(gobject.GObject):
 				if self._gstreamer_player is not None:
 					self._gstreamer_player.vol_down()
 			elif keyname == 'Escape':
-				self.feed_pane.set_position(840)
+				self.feed_tabs.set_current_page(0)
 		else: #regular desktop version..
 			if keyname == 'F11':
 				self.toggle_fullscreen()
@@ -1442,10 +1468,8 @@ class MainWindow(gobject.GObject):
 		self.entry_view.post_show_init()
 		if self.layout.endswith("planet"):
 			self._menu_widgettree.get_widget('entry_menu_item').hide()
-			self._menu_widgettree.get_widget('showkept_cb').show()
 		else:
 			self._menu_widgettree.get_widget('entry_menu_item').show()
-			self._menu_widgettree.get_widget('showkept_cb').hide()
 
 		self._notebook.show_only(N_FEEDS)
 		if not utils.HAS_SEARCH:
@@ -1464,9 +1488,6 @@ class MainWindow(gobject.GObject):
 	def is_changing_layout(self):
 		return self.changing_layout
 		
-	def on_unread_filter_toggled(self, event): 	 
-		self.feed_list_view.set_unread_toggle(self._filter_unread_checkbox.get_active()) 	 
-		
 	def display_status_message(self, m, update_category=U_STANDARD):
 		"""displays a status message on the main status bar.  If this is a polling update or download
 		   update, we don't overwrite what's there."""	
