@@ -13,7 +13,7 @@ import gettext
 import shutil
 import logging
 
-VERSION="3.8.8"
+VERSION="3.9.0"
 
 try:
 	from sqlite3 import OperationalError as OperationalError
@@ -141,6 +141,7 @@ else:
 		HAS_GSTREAMER = False
 
 if RUNNING_HILDON:
+	#having a status icon causes tons of problems (causes hildonn UI to crash)
 	HAS_STATUS_ICON = False
 	
 #DEBUG
@@ -597,7 +598,8 @@ def init_gtkmozembed():
 	p = subprocess.Popen(cmd, shell=True, close_fds=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
 	retval = p.wait()
 	stderr = p.stderr.read()
-	if len(stderr) > 1 or retval == 0:
+	stdout = p.stdout.read()
+	if len(stderr) > 1 or len(stdout) > 0:
 		print """***ERROR initializing mozilla.  PenguinTV may crash shortly.  
 You may need to export LD_LIBRARY_PATH=$MOZILLA_FIVE_HOME
 """
